@@ -14,7 +14,6 @@ class Statements(Resource):
         month: str,
         *,
         attach_pdf: bool = False,
-        encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
         **kwargs: Dict,
@@ -29,9 +28,6 @@ class Statements(Resource):
             "save_data": save_data,
         }
 
-        if encryption_key:
-            data.update(encryption_key=encryption_key)
-
         return self.session.post(
             self.endpoint, data=data, raise_exception=raise_exception, **kwargs
         )
